module Bitfinex
  module Funding
    # 列出放貸總績效
    # Ratelimit: 45 req/min
    # https://docs.bitfinex.com/reference#rest-auth-info-funding
    def funding_info(currency = "fUSD")
      res = request("auth/r/info/funding/#{currency}").body
      return JSON.parse(res)
    end

    # 列出所有正在掛單
    # Ratelimit: 45 req/min
    # https://docs.bitfinex.com/reference#rest-auth-funding-offers
    def funding_offers_all
      res = request("auth/r/funding/offers").body
      return JSON.parse(res)
    end

    # 列出currency掛單
    # Ratelimit: 45 req/min
    # https://docs.bitfinex.com/reference#rest-auth-funding-offers
    def funding_offers(currency = "fUSD")
      res = request("auth/r/funding/offers/#{currency}").body
      return JSON.parse(res)
    end

    # 取消指定掛單
    # https://docs.bitfinex.com/reference#rest-auth-cancel-order
    def funding_cancel_offer(id)
      res = request("auth/w/funding/offer/cancel", {
        id: id,
      }).body
      return JSON.parse(res)
    end

    # https://docs.bitfinex.com/reference#rest-auth-cancel-all-funding-offers
    def funding_cancel_all_offers(currency = "USD")
      res = request("auth/w/funding/offer/cancel/all", {
        currency: currency,
      }).body
      return JSON.parse(res)
    end

    # 掛單
    # https://docs.bitfinex.com/reference#submit-funding-offer
    def funding_create_offer(currency, amount, rate, period)
      # auth/w/funding/offer/submit
      request("auth/w/funding/offer/submit", {
        type: "LIMIT",
        symbol: currency, #fUSD
        amount: amount, #借款要是負的
        rate: rate,
        period: period,
        flags: 0,
      }).body
    end

    # https://docs.bitfinex.com/v1/reference#rest-auth-offers
    def funding_new_offer(params)
      res = v1_request("offer/new", params)
      res = JSON.parse(res)
      return res
    end

    # 所有正在借款列表
    # Ratelimit: 45 req/min
    # https://docs.bitfinex.com/reference#rest-auth-funding-credits
    def funding_credit_all
      res = request("auth/r/funding/credits").body
      return JSON.parse(res)
    end

    def funding_credit(currency = "fUSD")
      res = request("auth/r/funding/credits/#{currency}").body
      return JSON.parse(res)
    end

    def funding_loans(currency = "fUSD")
      res = request("auth/r/funding/loans/#{currency}").body
      return JSON.parse(res)
    end
  end
end
